import type { Metar } from '$lib/api/types/metar';

export const aviationWeatherApi = {
    /**
     * Fetches METAR data for a given ICAO code.
     * @param icao - The ICAO code (e.g., "EGKK")
     * @returns A Promise resolving to a Metar object or null if not found.
     */
    async fetchMetar(icao: string): Promise<Metar | null> {
        const url = `/api/metar/${encodeURIComponent(icao)}`;
        const response = await fetch(url);
        if (!response.ok) throw new Error(`Failed to fetch METAR: ${response.statusText}`);
        const data = await response.json();
        return data as Metar | null;
    }
};